Learn R Programming

div (version 0.3.1)

div_ci_median: Function to calculate the confidence interval for the median

Description

Function to calculate the confidence interval for the median

Usage

div_ci_median(x, conf = 0.95)

Arguments

x

numeric, data from which the median is calcualted

conf

numeric, the confidence interval as 1 - P(x < x0)

Value

ci (confidence interval object)

Examples

Run this code
# NOT RUN {
x <- 1:100
div_ci_median(x)
# }

Run the code above in your browser using DataLab